@@ -1,7 +1,8 @@
- calc_analytic_css <- function(chem.name=NULL,chem.cas = NULL,parameters=NULL,daily.dose=1,output.units='uM',model = 'pbtk',species='Human',concentration='plasma',suppress.messages=F,recalc.blood2plasma=F,default.to.human=F,tissue=NULL)
+ calc_analytic_css <- function(chem.name=NULL,chem.cas = NULL,parameters=NULL,daily.dose=1,output.units='uM',model = 'pbtk',species='Human',concentration='plasma',suppress.messages=F,recalc.blood2plasma=F,default.to.human=F,tissue=NULL,well.stirred.correction=T,Funbound.plasma.pc.correction=T,restrictive.clearance=T,...)
  {
-    physiology.data <- physiology.data 
     tissue.data <- tissue.data
+    physiology.data <- physiology.data
+    Tissue <- Species <- variable <- NULL
     
     if(is.null(chem.cas) & is.null(chem.name) & is.null(parameters)) stop('Must specify chem.cas, chem.name, or parameters.')
     
@@ -34,7 +35,7 @@
     if(tolower(model)=='pbtk')
     {
        if(is.null(parameters)){
-         parameters <- parameterize_pbtk(chem.cas=chem.cas,species=species,default.to.human=default.to.human)
+         parameters <- parameterize_pbtk(chem.cas=chem.cas,species=species,default.to.human=default.to.human,Funbound.plasma.pc.correction=Funbound.plasma.pc.correction,...)
          user.params <- F 
        }else{
          name.list <- c("BW","Clmetabolismc","Funbound.plasma","Fgutabs","Fhep.assay.correction","hematocrit","kdermabs","Kgut2pu","kgutabs","kinhabs","Kkidney2pu","Kliver2pu","Klung2pu","Krbc2pu","Krest2pu","million.cells.per.gliver","MW","Qcardiacc" ,"Qgfrc","Qgutf","Qkidneyf","Qliverf","Rblood2plasma","Vartc","Vgutc","Vkidneyc","Vliverc","Vlungc","Vrestc","Vvenc")
@@ -57,6 +58,7 @@
        Qrest <- Qcardiac-Qgut-Qliver-Qkidney
        Rblood2plasma <- parameters[['Rblood2plasma']]
        fub <- parameters[["Funbound.plasma"]]
+       if(!restrictive.clearance) Clmetabolism <- Clmetabolism / fub
 
        dose <- dose * parameters$Fgutabs
        
@@ -69,7 +71,7 @@
     else if (tolower(model)=='3compartmentss')
     {
       if (is.null(parameters)){
-        parameters <- parameterize_steadystate(chem.cas=chem.cas,species=species,default.to.human=default.to.human)
+        parameters <- parameterize_steadystate(chem.cas=chem.cas,species=species,default.to.human=default.to.human,Funbound.plasma.correction=Funbound.plasma.pc.correction,...)
         user.params <- F
       }else{
         name.list <- c("Clint","Funbound.plasma","Fhep.assay.correction","Qtotal.liverc","Qgfrc","BW","MW","Fgutabs","million.cells.per.gliver","Vliverc","liver.density")
@@ -79,16 +81,17 @@
       if(parameters$Funbound.plasma == 0) stop('Fraction unbound plasma cannot be zero.  Use calc_mc_css or get_wetmore_css to predict steady state for this chemical with three compartment steady state model.')
       
       dose <- dose * parameters$Fgutabs
-      Css <- dose/(parameters$Qgfrc/parameters[['BW']]^.25 * parameters$Funbound.plasma + calc_hepatic_clearance(chem.name=chem.name,chem.cas=chem.cas,species=species,parameters=parameters,suppress.messages=T))
+      fub <- parameters$Funbound.plasma
+      Css <- dose/(parameters$Qgfrc/parameters[['BW']]^.25 * fub + calc_hepatic_clearance(parameters=parameters,chem.cas=chem.cas,chem.name=chem.name,species=species,well.stirred.correction=well.stirred.correction,suppress.messages=T,restrictive.clearance=restrictive.clearance))
       if (tolower(concentration)=='blood')
       {
         if(is.null(chem.name) & is.null(chem.cas)) stop("Enter chem.name or chem.cas with appropriate species and default.to.human options for desired concentration.")
-        Rb2p <- calc_rblood2plasma(chem.cas=chem.cas,chem.name=chem.name,species=species,default.to.human=default.to.human)
+        Rb2p <- available_rblood2plasma(chem.cas=chem.cas,species=species,Funbound.plasma.pc.correction=Funbound.plasma.pc.correction)
         Css <- Css * Rb2p
-      } else if(tolower(concentration)!='plasma') stop("Only blood and plasma concentrations are calculated.")      
+      } else if (tolower(concentration)!='plasma') stop("Only blood and plasma concentrations are calculated.")      
     }else if(tolower(model) == '1compartment'){
       if(is.null(parameters)){
-        parameters <- parameterize_1comp(chem.cas=chem.cas,species=species,default.to.human=default.to.human)
+        parameters <- parameterize_1comp(chem.cas=chem.cas,species=species,default.to.human=default.to.human,Funbound.plasma.pc.correction=Funbound.plasma.pc.correction,restrictive.clearance=restrictive.clearance,...)
         user.params <- F
       }else{
         name.list <- c("Vdist","million.cells.per.gliver","kelim","kgutabs","Rblood2plasma","MW","hematocrit","Fgutabs")
@@ -103,7 +106,7 @@
       } else if (tolower(concentration)!='plasma') stop("Only blood and plasma concentrations are calculated.")
     }else if(tolower(model) == '3compartment'){
       if (is.null(parameters)){
-        parameters <- parameterize_3comp(chem.cas=chem.cas,species=species,default.to.human=default.to.human)
+        parameters <- parameterize_3comp(chem.cas=chem.cas,species=species,default.to.human=default.to.human,Funbound.plasma.pc.correction=Funbound.plasma.pc.correction,...)
         user.params <- F
       }else{
         name.list <- c("BW","Clmetabolismc","Funbound.plasma","Fgutabs","Fhep.assay.correction","hematocrit","Kgut2pu","Krbc2pu","kgutabs","Kliver2pu","Krest2pu","million.cells.per.gliver","MW","Qcardiacc","Qgfrc","Qgutf","Qliverf","Rblood2plasma","Vgutc","Vliverc","Vrestc")
@@ -115,7 +118,10 @@
       }
 
       dose <- dose * parameters$Fgutabs
-      Css <- dose * parameters[['BW']]^0.25  / (parameters$Clmetabolismc * parameters[['BW']]^0.25  + parameters$Qgfrc * (parameters$Qliverf + parameters$Qgutf) * parameters$Qcardiacc / ((parameters$Qliverf + parameters$Qgutf) * parameters$Qcardiacc + parameters$Funbound.plasma * parameters$Qgfrc / parameters$Rblood2plasma)) / parameters$Funbound.plasma
+      fub <- parameters$Funbound.plasma
+      Clmetabolism <- parameters$Clmetabolismc
+      if(!restrictive.clearance) Clmetabolism <- Clmetabolism / fub
+      Css <- dose * parameters[['BW']]^0.25  / (Clmetabolism * parameters[['BW']]^0.25  + parameters$Qgfrc * (parameters$Qliverf + parameters$Qgutf) * parameters$Qcardiacc / ((parameters$Qliverf + parameters$Qgutf) * parameters$Qcardiacc + fub * parameters$Qgfrc / parameters$Rblood2plasma)) / fub
       if (tolower(concentration)=='blood')
       {
          Css <- Css * parameters[['Rblood2plasma']]
@@ -137,13 +143,11 @@
       if(is.null(chem.name) & is.null(chem.cas)) stop("Enter chem.name or chem.cas with appropriate species and default.to.human options for desired tissue concentration.")
       pcs <- predict_partitioning_schmitt(chem.cas=chem.cas,species=species,default.to.human=default.to.human)
       parameters <- c(parameters,pcs[!substr(names(pcs),1,nchar(names(pcs))-3) %in% substr(names(parameters),1,nchar(names(parameters))-3)])
-    }      
-    if(!'Rblood2plasma' %in% names(parameters) & tolower(tissue) %in% c('gut','kidney','liver')) parameters[['Rblood2plasma']] <- calc_rblood2plasma(chem.cas=chem.cas,species=species,default.to.human=default.to.human)
-        #parameters[['hematocrit']] <-  physiology.data[physiology.data[,'Parameter']=='Hematocrit',paste0(toupper(substr(species,1,1)), tolower(substr(species,2,nchar(species))))]
-       #1 - parameters[['hematocrit']] + parameters[['hematocrit']] * parameters[["Krbc2pu"]] * parameters[['Funbound.plasma']]
+    }
+     if(!'Rblood2plasma' %in% names(parameters) & tolower(tissue) %in% c('gut','kidney','liver')) parameters[['Rblood2plasma']] <- available_rblood2plasma(chem.cas=chem.cas,chem.name=chem.name,species=species,Funbound.plasma.pc.correction=Funbound.plasma.pc.correction)    
     if(tissue == 'gut'){
       if(!all(c('Qcardiacc','Qgutf') %in% names(parameters))){
-        Qgut <- tissue.data[tissue.data[,"Tissue"]=='gut',paste0(toupper(substr(species,1,1)), tolower(substr(species,2,nchar(species)))," Flow (mL/min/kg^(3/4))")] * 60 / 1000 / parameters$BW^.25
+        Qgut <- as.numeric(subset(tissue.data,Tissue == 'gut' & tolower(Species) == tolower(species) & variable == 'Flow (mL/min/kg^(3/4))')[,'value']) * 60 / 1000 / parameters$BW^.25
         if(user.params) warning(paste(species,'gut flow used in calculating',tissue,'concentration.  Species of parameters should match species argument of input function.'))
       }else Qgut <- parameters$Qgutf * parameters$Qcardiacc / parameters$BW^0.25
       Css <- parameters[['Kgut2pu']] * parameters[['Funbound.plasma']] * (Css + dose / (Qgut * parameters[['Rblood2plasma']]))
@@ -155,7 +159,7 @@
       if('Qtotal.liverc' %in% names(parameters)) Qliver <- parameters$Qtotal.liverc / parameters$BW^0.25
       else if(all(c('Qgutf','Qliverf','Qcardiacc') %in% names(parameters))) Qliver <- (parameters$Qliverf + parameters$Qgutf) * parameters$Qcardiacc / parameters$BW^0.25
       else{
-        Qliver <- tissue.data[tissue.data[,"Tissue"]=='liver',paste0(toupper(substr(species,1,1)), tolower(substr(species,2,nchar(species)))," Flow (mL/min/kg^(3/4))")] * 60 / 1000 / parameters$BW^.25
+        Qliver <- as.numeric(subset(tissue.data,Tissue == 'liver' & tolower(Species) == tolower(species) & variable == 'Flow (mL/min/kg^(3/4))')[,'value']) * 60 / 1000 / parameters$BW^.25
         if(user.params) warning(paste(species,'liver flow used in calculating',tissue,'concentration.  Species of parameters should match species argument of input function.'))
       }
       if('Clint' %in% names(parameters)) parameters[['Clmetabolismc']] <- calc_hepatic_clearance(parameters=parameters,hepatic.model='unscaled',suppress.messages=T)
@@ -163,14 +167,17 @@
         if(is.null(chem.name) & is.null(chem.cas)) stop("Include Clmetabolismc (unscaled) in parameters or enter chem.name or chem.cas with appropriate species for desired tissue concentration.")
         parameters[['Clmetabolismc']] <- calc_hepatic_clearance(chem.cas=chem.cas,species=species,hepatic.model='unscaled',suppress.messages=T)
       }
-      Css <- parameters[['Kliver2pu']] * parameters[['Funbound.plasma']] * (dose + Qliver * Css * parameters[['Rblood2plasma']]) / (parameters[['Clmetabolismc']] * parameters[['Funbound.plasma']] + Qliver * parameters[['Rblood2plasma']])
+      fub <- parameters[['Funbound.plasma']]
+      Clmetabolism <- parameters$Clmetabolismc
+      if(!restrictive.clearance) Clmetabolism <- Clmetabolism / fub
+      Css <- parameters[['Kliver2pu']] * fub * (dose + Qliver * Css * parameters[['Rblood2plasma']]) / (Clmetabolism * fub + Qliver * parameters[['Rblood2plasma']])
       if(unit.change){
         Css <- Css / parameters$MW * 1000
         output.units <- 'uM'
       }
     }else if(tissue == 'kidney'){
       if(!all(c('Qcardiacc','Qkidneyf') %in% names(parameters))){
-        Qkidney <- tissue.data[tissue.data[,"Tissue"]=='kidney',paste0(toupper(substr(species,1,1)), tolower(substr(species,2,nchar(species)))," Flow (mL/min/kg^(3/4))")] * 60 / 1000 / parameters$BW^0.25 
+        Qkidney <- as.numeric(subset(tissue.data,Tissue == 'kidney' & tolower(Species) == tolower(species) & variable == 'Flow (mL/min/kg^(3/4))')[,'value']) * 60 / 1000 / parameters$BW^0.25 
         if(user.params) warning(paste(species,'kidney flow used in calculating',tissue,'concentration.  Species of parameters should match species argument of input function.'))
       }else Qkidney <- parameters$Qkidneyf * parameters$Qcardiacc / parameters$BW^0.25
       if(! 'Qgfrc' %in% names(parameters)){
