@@ -1,4 +1,4 @@
-calc_stats <-function(days,chem.name=NULL,chem.cas=NULL,parameters=NULL,stats=c("AUC","peak","mean"),species='Human',exclude.fub.zero=F,daily.dose=1,dose=NULL,doses.per.day=NULL,output.units='uM',concentration='plasma',model='pbtk',suppress.messages=F,...)
+calc_stats <-function(days,chem.name=NULL,chem.cas=NULL,parameters=NULL,stats=c("AUC","peak","mean"),species='Human',exclude.fub.zero=F,daily.dose=1,dose=NULL,doses.per.day=NULL,output.units='uM',concentration='plasma',model='pbtk',default.to.human=F,suppress.messages=F,...)
 {
   AUC <- NULL
   peak <- NULL
@@ -7,7 +7,7 @@ calc_stats <-function(days,chem.name=NULL,chem.cas=NULL,parameters=NULL,stats=c(
   
   if(is.null(chem.name) & is.null(chem.cas) & is.null(parameters)){
     for(this.CAS in get_cheminfo(species=species,exclude.fub.zero = exclude.fub.zero,model=model)){
-      stat <- calc_chem_stats(chem.cas=this.CAS,days=days,stats=stats,species=species,dose=dose,daily.dose=daily.dose,doses.per.day=doses.per.day,concentration=concentration,output.units=output.units,model=model,suppress.messages=T,...)
+      stat <- calc_chem_stats(chem.cas=this.CAS,days=days,stats=stats,species=species,dose=dose,daily.dose=daily.dose,doses.per.day=doses.per.day,concentration=concentration,output.units=output.units,model=model,default.to.human=default.to.human,suppress.messages=T,...)
 
       if(length(stat)==1){
         out[this.CAS] <-  stat 
@@ -28,7 +28,7 @@ calc_stats <-function(days,chem.name=NULL,chem.cas=NULL,parameters=NULL,stats=c(
       if('auc' %in% tolower(stats)) cat("AUC is area under plasma concentration curve in",output.units,"* days units.\n")
     }
   }else{
-    out <- calc_chem_stats(chem.name=chem.name,chem.cas=chem.cas,parameters=parameters,days=days,stats=stats,species=species,daily.dose=daily.dose,dose=dose,doses.per.day=doses.per.day,concentration=concentration,output.units=output.units,model=model,suppress.messages=suppress.messages,...)
+    out <- calc_chem_stats(chem.name=chem.name,chem.cas=chem.cas,parameters=parameters,days=days,stats=stats,species=species,daily.dose=daily.dose,dose=dose,doses.per.day=doses.per.day,concentration=concentration,output.units=output.units,model=model,default.to.human=default.to.human,suppress.messages=suppress.messages,...)
   } 
   return(out)
 }
\ No newline at end of file
