@@ -73,8 +73,12 @@ get_cheminfo <- function(info="CAS",species="Human",exclude.fub.zero=NA,fub.lod.
       if('logp' %in% tolower(info)) info <- c('logP',info[tolower(info) != 'logp'])
       if('compound' %in% tolower(info)) info <- c('Compound',info[tolower(info) != 'compound'])
       if('cas' %in% tolower(info)) info <- c('CAS',info[tolower(info) != 'cas'])
+      if('dsstox_substance_id' %in% tolower(info)) info <- c('DSSTox_Substance_Id',info[tolower(info) != 'dsstox_substance_id'])
+      if('structure_formula' %in% tolower(info)) info <- c('Structure_Formula',info[tolower(info) != 'structure_formula'])
+      if('substance_type' %in% tolower(info)) info <- c('Substance_Type',info[tolower(info) != 'substance_type'])
+  
     
-    valid.info <- c("Compound","CAS","logP","pKa_Accept","pKa_Donor","MW","Clint","Clint.pValue","Funbound.plasma")
+    valid.info <- c("Compound","CAS","logP","pKa_Accept","pKa_Donor","MW","Clint","Clint.pValue","Funbound.plasma","DSSTox_Substance_Id","Structure_Formula","Substance_Type")
   
     if (any(toupper(info)=="ALL")) info <- valid.info
     
