@@ -1,16 +1,17 @@
-parameterize_1comp <- function(chem.cas=NULL,chem.name=NULL,species='Human',default.to.human=F)
+parameterize_1comp <- function(chem.cas=NULL,chem.name=NULL,species='Human',default.to.human=F,Funbound.plasma.pc.correction=T,restrictive.clearance=T,well.stirred.correction=T,suppress.messages=F)
 {
  physiology.data <- physiology.data
 if(is.null(chem.cas) & is.null(chem.name)) stop('Must specify chem.name or chem.cas')
 params <- list()
 
-params[['Vdist']] <- calc_vdist(chem.cas=chem.cas,chem.name=chem.name,species=species,default.to.human=default.to.human,suppress.messages=T)
+params[['Vdist']] <- calc_vdist(chem.cas=chem.cas,chem.name=chem.name,species=species,default.to.human=default.to.human,Funbound.plasma.pc.correction=Funbound.plasma.pc.correction,suppress.messages=T)
 
-params[['kelim']] <- calc_elimination_rate(chem.cas=chem.cas,chem.name=chem.name,species=species,suppress.messages=T,default.to.human=default.to.human)
+params[['kelim']] <- calc_elimination_rate(chem.cas=chem.cas,chem.name=chem.name,species=species,suppress.messages=T,default.to.human=default.to.human,
+                                           Funbound.plasma.pc.correction=Funbound.plasma.pc.correction,restrictive.clearance=restrictive.clearance,well.stirred.correction=well.stirred.correction)
 
 params[['kgutabs']] <- 1
 
-params[['Rblood2plasma']] <- calc_rblood2plasma(chem.cas=chem.cas,chem.name=chem.name,species=species,default.to.human=default.to.human)
+params[['Rblood2plasma']] <- available_rblood2plasma(chem.cas=chem.cas,chem.name=chem.name,species=species,Funbound.plasma.pc.correction=Funbound.plasma.pc.correction)
 
 params[['million.cells.per.gliver']] <- 110
 
@@ -38,8 +39,5 @@ params[['MW']] <- get_physchem_param("MW",chem.CAS=chem.cas)
   
   params[['Fgutabs']] <- Fgutabs
 
-
-
 return(params)
-
 }
\ No newline at end of file
